Overview
========
pyNlple - a library with basic NLP utils. Also includes methods and APIs for data accessing/writing.

Requirements
============

- numpy
- scikit-learn
- requests>=2.9.1
- pandas>=0.19.0
- gensim>=2.1.0
- elasticsearch>=2.0.0,<3.0.0
- pymorphy2

Installation
============

Run setup.py install

* name inspired by https://www.youtube.com/watch?v=1W3sslyiUfg
** yeah, we had "PYthon" and "NLP" procedures, so...
*** and yeah, try to read it as #pineapple http://www.veepy.com/wp-content/uploads/2015/05/1965.jpg